FriConfig

Struct FriConfig 

pub struct FriConfig<F> {
    pub log_blowup: usize,
    pub num_queries: usize,
    pub proof_of_work_bits: usize,
    /* private fields */
}

Fields

log_blowup: usizenum_queries: usizeproof_of_work_bits: usize

Implementations

Source

impl<F> FriConfig<F>

pub const fn new( log_blowup: usize, num_queries: usize, proof_of_work_bits: usize, ) -> Self

pub fn default_fri_config() -> Self

This FRI config relies on a conjecture for achieving 100 bits of security. Given Gruen and Diamond’s recent result, we have increased the number of queries to 94 to be on the safe side. (With the original conjecture, we would achieve 100 bits of security with 84 queries and 16 bits of grinding.)

pub const fn log_blowup(&self) -> usize

pub const fn num_queries(&self) -> usize

pub const fn proof_of_work_bits(&self) -> usize